@@ -63,10 +63,10 @@ class BalanceSheet:
             self.parent = parent
 
         def __enter__(self):
-            self.parent._engaged = False
+            self.parent._engaged = False # disengage()
 
         def __exit__(self, exc_type, exc_val, exc_tb):
-            self.parent.engage()
+            self.parent._engaged = True # engage()
 
     def __init__(self, owner):
         """
